import { createBrowserRouter, RouterProvider } from 'react-router-dom';
import { ColorFunctionProvider } from './ColorFunctionContext';
import { Notifications } from './components/Notifications';
import { Harmonies } from './pages/Harmonies';
import { Home } from './pages/Home';
import { MainLayout } from './pages/MainLayout';
import { NewScheme } from './pages/NewScheme';
import { SchemeDetail } from './pages/SchemeDetail';
import { SchemeNotFound } from './pages/SchemeNotFound';
import { Schemes } from './pages/Schemes';
import { Wheels } from './pages/Wheels';

const routes = createBrowserRouter([
  {
    path: '/',
    element: <MainLayout />,
    children: [
      { index: true, element: <Home /> },
      {
        path: 'schemes',
        element: <Schemes />,
        children: [
          { path: 'new', element: <NewScheme /> },
          { path: 'not-found', element: <SchemeNotFound /> },
          { path: ':id', element: <SchemeDetail /> },
        ],
      },
      { path: 'harmonies', element: <Harmonies /> },
      { path: 'wheels', element: <Wheels /> },
    ],
  },
]);

export function App() {
  return (
    <ColorFunctionProvider>
      <Notifications>
        <title>Color Lab</title>
        <RouterProvider router={routes}></RouterProvider>
      </Notifications>
    </ColorFunctionProvider>
  );
}
