import cx from 'clsx';
import { includes } from 'lodash-es';
import { useMemo } from 'react';
import { useColorFunction } from '../../ColorFunctionContext';
import { ColorColumn } from './ColorColumn';
import styles from './ColorWheel.module.css';

type ColorWheelProps = {
  originColor?: string;
  highlightMode?:
    | 'complementary'
    | 'analogous'
    | 'analogous_with_complementary'
    | 'triadic'
    | 'split_complementary'
    | 'tetradic'
    | 'flip_tetradic'
    | 'square';
};

const wheelRotates = [0, 30, 60, 90, 120, 150, 180, 210, 240, 270, 300, 330];
const highlightSeries = {
  complementary: [0, 180],
  analogous: [0, 30, 330],
  analogous_with_complementary: [0, 30, 180, 330],
  triadic: [0, 120, 240],
  split_complementary: [0, 150, 210],
  tetradic: [0, 60, 180, 240],
  flip_tetradic: [0, 120, 180, 300],
  square: [0, 90, 180, 270],
};

export function ColorWheel({
  originColor = '000000',
  highlightMode = 'complementary',
}: ColorWheelProps) {
  const { colorFn } = useColorFunction();
  const wheelColors = useMemo(() => {
    return wheelRotates.map((rotate) => {
      try {
        const color = colorFn?.shift_hue(originColor, rotate);
        return { color: color ?? '000000', rotate };
      } catch (e) {
        console.error('[Generate color wheel]', e);
      }
      return { color: '000000', rotate };
    });
  }, [originColor]);

  return (
    <div className={styles.wheel_view}>
      <h5>Color Wheel</h5>
      <div className={cx('center', styles.wheel_place)}>
        <div className={styles.wheel_container}>
          {wheelColors.map(({ color, rotate }) => (
            <ColorColumn
              key={`${color}-${rotate}`}
              rootColor={color}
              rotate={rotate}
              actived={includes(highlightSeries[highlightMode], rotate)}
            />
          ))}
        </div>
      </div>
    </div>
  );
}
